summaryrefslogtreecommitdiffstats
path: root/pyuic2/domtool.h
diff options
context:
space:
mode:
Diffstat (limited to 'pyuic2/domtool.h')
-rw-r--r--pyuic2/domtool.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/pyuic2/domtool.h b/pyuic2/domtool.h
index 7230bce..434729b 100644
--- a/pyuic2/domtool.h
+++ b/pyuic2/domtool.h
@@ -2,7 +2,7 @@
** Copyright (C) 2000 Troll Tech AS. All rights reserved.
** Copyright (C) 2000, 2001 Phil Thompson <phil@river-bank.demon.co.uk>
**
** This file is part of Qt GUI Designer.
**
** This file may be distributed under the terms of the GNU General
** Public License version 2 as published by the Free Software
@@ -24,16 +24,16 @@
#include <qdom.h>
-class DomTool : public Qt
+class DomTool : public TQt
{
public:
- static QVariant readProperty( const QDomElement& e, const QString& name, const QVariant& defValue );
- static bool hasProperty( const QDomElement& e, const QString& name );
- static QVariant elementToVariant( const QDomElement& e, const QVariant& defValue );
- static QVariant elementToVariant( const QDomElement& e, const QVariant& defValue, QString &comment );
- static QVariant readAttribute( const QDomElement& e, const QString& name, const QVariant& defValue );
- static bool hasAttribute( const QDomElement& e, const QString& name );
- static QColor readColor( const QDomElement &e );
+ static TQVariant readProperty( const TQDomElement& e, const TQString& name, const TQVariant& defValue );
+ static bool hasProperty( const TQDomElement& e, const TQString& name );
+ static TQVariant elementToVariant( const TQDomElement& e, const TQVariant& defValue );
+ static TQVariant elementToVariant( const TQDomElement& e, const TQVariant& defValue, TQString &comment );
+ static TQVariant readAttribute( const TQDomElement& e, const TQString& name, const TQVariant& defValue );
+ static bool hasAttribute( const TQDomElement& e, const TQString& name );
+ static TQColor readColor( const TQDomElement &e );
};
@@ -2,7 +2,7 @@
** Copyright (C) 2000, 2001 Phil Thompson <phil@river-bank.demon.co.uk>
**
-** This file is part of Qt GUI Designer.
+** This file is part of TQt GUI Designer.
**
** This file may be distributed under the terms of the GNU General